@@ -11,7 +11,7 @@ from matplotlib.colors import LightSource
 from importlib import import_module
 
 from mpl_plotter.methods.mock_data import MockData
-from mpl_plotter.methods.helpers import print_color
+from Alexandria.general.console import print_color
 
 
 class canvas:
