@@ -11,7 +11,7 @@ from matplotlib import font_manager as font_manager
 from matplotlib.ticker import FormatStrFormatter
 
 from mpl_plotter.methods.mock_data import MockData
-from mpl_plotter.methods.helpers import print_color
+from Alexandria.general.console import print_color
 
 
 class canvas:
@@ -1209,7 +1209,7 @@ class fill_area(plot, std_input):
                                      alpha=self.alpha, label=self.plot_label)
             if self.between is False and self.below is False and self.above is False:
                 print_color('No area chosen to fill: specify whether to fill "between", "below" or "above" the curves',
-                            'grey')
+                            'blue')
         else:
             self.ax.fill_between(self.x, self.y, np.zeros(self.y.shape), facecolor=self.color, alpha=self.alpha)
 
